%bcond_without  jp_minimal

Name:           jackson-jaxrs-providers
Version:        2.17.2
Release:        %mkrel 1
Group:          Development/Java
Summary:        Jackson JAX-RS providers
License:        Apache-2.0

URL:            https://github.com/FasterXML/jackson-jaxrs-providers
Source0:        %{url}/archive/%{name}-%{version}.tar.gz

BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

BuildRequires:  maven-local
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-core) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson.core:jackson-databind) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson.module:jackson-module-jaxb-annotations) >= %{version}
BuildRequires:  mvn(com.fasterxml.jackson:jackson-base:pom:) >= %{version}
BuildRequires:  mvn(com.google.code.maven-replacer-plugin:replacer)
BuildRequires:  mvn(org.jboss.spec.javax.ws.rs:jboss-jaxrs-api_2.0_spec)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)

%if %{without jp_minimal}
BuildRequires:  mvn(com.fasterxml.jackson.dataformat:jackson-dataformat-cbor)
BuildRequires:  mvn(com.fasterxml.jackson.dataformat:jackson-dataformat-smile)
BuildRequires:  mvn(com.fasterxml.jackson.dataformat:jackson-dataformat-xml)
BuildRequires:  mvn(com.fasterxml.jackson.dataformat:jackson-dataformat-yaml)
BuildRequires:  mvn(org.glassfish.jersey.containers:jersey-container-servlet)
BuildRequires:  mvn(org.glassfish.jersey.core:jersey-server)
BuildRequires:  mvn(org.jboss.resteasy:resteasy-jaxrs)
%endif

%if %{with jp_minimal}
Obsoletes:      jackson-jaxrs-cbor-provider < 2.10.0-1
Obsoletes:      jackson-jaxrs-smile-provider < 2.10.0-1
Obsoletes:      jackson-jaxrs-xml-provider < 2.10.0-1
Obsoletes:      jackson-jaxrs-yaml-provider < 2.10.0-1
%endif

%description
This is a multi-module project that contains Jackson-based JAX-RS providers for
following data formats: JSON, Smile (binary JSON), XML, CBOR (another kind of
binary JSON), YAML.

%package -n jackson-jaxrs-json-provider
Summary:       Jackson-JAXRS-JSON

%description -n jackson-jaxrs-json-provider
Functionality to handle JSON input/output for JAX-RS implementations
(like Jersey and RESTeasy) using standard Jackson data binding.

%if %{without jp_minimal}
%package -n jackson-jaxrs-cbor-provider
Summary:       Jackson-JAXRS-CBOR

%description -n jackson-jaxrs-cbor-provider
Functionality to handle CBOR encoded input/output for JAX-RS implementations
(like Jersey and RESTeasy) using standard Jackson data binding.

%package -n jackson-jaxrs-smile-provider
Summary:       Jackson-JAXRS-Smile

%description -n jackson-jaxrs-smile-provider
Functionality to handle Smile (binary JSON) input/output for
JAX-RS implementations (like Jersey and RESTeasy) using standard
Jackson data binding.

%package -n jackson-jaxrs-xml-provider
Summary:       Jackson-JAXRS-XML

%description -n jackson-jaxrs-xml-provider
Functionality to handle Smile XML input/output for JAX-RS implementations
(like Jersey and RESTeasy) using standard Jackson data binding.

%package -n jackson-jaxrs-yaml-provider
Summary:       Jackson-JAXRS-YAML

%description -n jackson-jaxrs-yaml-provider
Functionality to handle YAML input/output for JAX-RS implementations
(like Jersey and RESTeasy) using standard Jackson data binding.
%endif

%package datatypes
Summary: Functionality for reading/writing core JAX-RS helper types

%description datatypes
Functionality for reading/writing core JAX-RS helper types.

%package parent
Summary: Parent for Jackson JAX-RS providers

%description parent
Parent POM for Jackson JAX-RS providers.

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

cp -p xml/src/main/resources/META-INF/LICENSE .
cp -p xml/src/main/resources/META-INF/NOTICE .
sed -i 's/\r//' LICENSE NOTICE

%pom_remove_plugin -r :moditect-maven-plugin
%pom_remove_plugin "de.jjohannes:gradle-module-metadata-maven-plugin"

# Disable jar with no-meta-inf-services classifier, breaks build
%pom_remove_plugin :maven-jar-plugin cbor
%pom_remove_plugin :maven-jar-plugin json
%pom_remove_plugin :maven-jar-plugin smile
%pom_remove_plugin :maven-jar-plugin xml
%pom_remove_plugin :maven-jar-plugin yaml
%pom_remove_plugin :maven-jar-plugin datatypes

# Replace jakarta-ws-rs with jboss-jaxrs-2.0-api
%pom_change_dep javax.ws.rs:javax.ws.rs-api org.jboss.spec.javax.ws.rs:jboss-jaxrs-api_2.0_spec

# Add missing deps to fix java.lang.ClassNotFoundException during tests
%pom_add_dep com.google.guava:guava:18.0:test datatypes cbor json smile xml yaml
%pom_add_dep org.ow2.asm:asm:5.1:test cbor json smile xml yaml

# Circular dep?
%pom_remove_dep org.jboss.resteasy:resteasy-jackson2-provider json
rm json/src/test/java/com/fasterxml/jackson/jaxrs/json/resteasy/RestEasyProviderLoadingTest.java

%if %{with jp_minimal}
# Disable extra test deps
%pom_remove_dep org.glassfish.jersey.core:
%pom_remove_dep org.glassfish.jersey.containers:
# Disable extra providers
%pom_disable_module cbor
%pom_disable_module smile
%pom_disable_module xml
%pom_disable_module yaml
%endif

%build
%if %{with jp_minimal}
%mvn_build -s -f
%else
%mvn_build -s
%endif

%install
%mvn_install

%files -f .mfiles-jackson-jaxrs-base
%doc README.md release-notes/*
%license LICENSE NOTICE

%files -n jackson-jaxrs-json-provider -f .mfiles-jackson-jaxrs-json-provider
%if %{without jp_minimal}
%files -n jackson-jaxrs-cbor-provider -f .mfiles-jackson-jaxrs-cbor-provider
%files -n jackson-jaxrs-smile-provider -f .mfiles-jackson-jaxrs-smile-provider
%files -n jackson-jaxrs-xml-provider -f .mfiles-jackson-jaxrs-xml-provider
%files -n jackson-jaxrs-yaml-provider -f .mfiles-jackson-jaxrs-yaml-provider
%endif

%files datatypes -f .mfiles-jackson-datatype-jaxrs
%license LICENSE NOTICE

%files parent -f .mfiles-jackson-jaxrs-providers
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE



%changelog
* Sun Sep 01 2024 neoclust <neoclust> 2.17.2-1.mga10
+ Revision: 2092502
- New version 2.17.2

* Fri May 24 2024 ns80 <ns80> 2.17.1-1.mga10
+ Revision: 2066999
- new version 2.17.1 for java 21

* Thu Sep 14 2023 daviddavid <daviddavid> 2.15.2-1.mga10
+ Revision: 1986694
- Update to version 2.15.2

* Sat Mar 26 2022 umeabot <umeabot> 2.11.4-2.mga9
+ Revision: 1827724
- Mageia 9 Mass Rebuild

* Mon Mar 01 2021 daviddavid <daviddavid> 2.11.4-1.mga9
+ Revision: 1694871
- Update to version 2.11.4

* Wed Oct 21 2020 daviddavid <daviddavid> 2.11.3-1.mga8
+ Revision: 1637881
- Update to version 2.11.3

* Sat Sep 05 2020 daviddavid <daviddavid> 2.11.2-1.mga8
+ Revision: 1622437
- Update to version 2.11.2

* Mon Feb 17 2020 umeabot <umeabot> 2.10.0-2.mga8
+ Revision: 1537407
- Mageia 8 Mass Rebuild

* Thu Oct 31 2019 daviddavid <daviddavid> 2.10.0-1.mga8
+ Revision: 1457001
- Update to version 2.10.0
- Build with minimized dependencies

* Thu Feb 07 2019 daviddavid <daviddavid> 2.9.8-1.mga7
+ Revision: 1363857
- Update to latest upstream release 2.9.8

* Mon Dec 03 2018 daviddavid <daviddavid> 2.9.4-1.mga7
+ Revision: 1337780
- new version: 2.9.4 (sync with fc29)

* Tue Sep 18 2018 umeabot <umeabot> 2.7.6-2.mga7
+ Revision: 1262193
- Mageia 7 Mass Rebuild

* Fri May 12 2017 neoclust <neoclust> 2.7.6-1.mga6
+ Revision: 1100644
- New version 2.7.6

* Wed Mar 02 2016 neoclust <neoclust> 2.6.3-4.mga6
+ Revision: 982371
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 2.6.3-3.mga6
+ Revision: 976411
- First rebuild of the java stack
- sync package jackson-jaxrs-providers with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Dec 28 2014 pterjan <pterjan> 2.4.1-2.mga5
+ Revision: 806762
- Clean rebuild
- Sync with Fedora 21 (update to 2.4.1)

* Wed Oct 15 2014 umeabot <umeabot> 2.2.2-4.mga5
+ Revision: 750919
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- rebuild for missing pythoneggs deps

* Sat Oct 12 2013 dmorgan <dmorgan> 2.2.2-1.mga4
+ Revision: 495574
- imported package jackson-jaxrs-providers


* Wed Jul 17 2013 gil cattaneo <puntogil@libero.it> 2.2.2-1
- update to 2.2.2
- renamed jackson-jaxrs-providers

* Tue Jul 16 2013 gil cattaneo <puntogil@libero.it> 2.1.5-1
- update to 2.1.5

* Wed Oct 24 2012 gil cattaneo <puntogil@libero.it> 2.1.0-1
- update to 2.1.0
- renamed jackson2-jaxrs-json-provider

* Thu Sep 13 2012 gil cattaneo <puntogil@libero.it> 2.0.5-1
- initial rpm
